@@ -14,6 +14,8 @@ key = {
   "g2_err": "/exchange/norm-0-stderr",
   "saxs_2d": "/exchange/pixelSum",
   "Int_t": "/exchange/frameSum",
+  "avg_frames": "/xpcs/avg_frames",
+  "stride_frames": "/xpcs/stride_frames",
   "ccd_x0": "/measurement/instrument/acquisition/beam_center_x",
   "ccd_y0": "/measurement/instrument/acquisition/beam_center_y",
   "det_dist": "/measurement/instrument/detector/distance",
@@ -26,6 +28,14 @@ key = {
   "g2_full": "/exchange/g2full",
   "g2_partials": "/exchange/g2partials",
   "G2": "/exchange/G2",
-  "IP": "/exchange/IF",
-  "IF": "/exchange/IP"
+  "IP": "/exchange/IP",
+  "IF": "/exchange/IF",
+  "snophi": "/xpcs/snophi",
+  "snoq": "/xpcs/snoq",
+  "sphilist": "/xpcs/sphilist",
+  "dnophi": "/xpcs/dnophi",
+  "dnoq": "/xpcs/dnoq",
+  "dphilist": "/xpcs/dphilist",
+  "sphispan": "/xpcs/sphispan",
+  "sqspan": "/xpcs/sqspan",
 }
