@@ -98,6 +98,13 @@ class FileLocator(object):
         if max_cache_size is None:
             # 2G
             self.max_cache_size = 1024 ** 3 * 2
+    
+    def set_path(self, path):
+        self.path = path
+    
+    def clear(self):
+        self.source.clear()
+        self.source_search.clear()
 
     def get_type(self, fname):
         return get_type(pjoin(self.cwd, fname))
@@ -243,7 +250,14 @@ class FileLocator(object):
         if filter_type == 'prefix':
             ans = [x for x in self.source if x.startswith(val)]
         elif filter_type == 'substr':
-            ans = [x for x in self.source if val in x]
+            # split by white space
+            filter_str = val.split()
+            def func(x):
+                for t in filter_str:
+                    if t not in x:
+                        return False
+                return True
+            ans = [x for x in self.source if func(x)]
         self.source_search.replace(ans)
 
         return
