@@ -1,17 +1,16 @@
+import os
 from PyQt5 import QtCore
 from PyQt5.QtCore import QObject, pyqtSlot
 import logging
-import os
+import uuid
+import time
 import numpy as np
 from sklearn.cluster import k_means as sk_kmeans
 from ..fileIO.hdf_reader import put
 from ..xpcs_file import XpcsFile as XF
 from collections import deque
 from shutil import copyfile
-import time
 from ..helper.listmodel import ListDataModel
-import uuid
-import time
 import pyqtgraph as pg
 
 
@@ -141,8 +140,6 @@ class AverageToolbox(QtCore.QRunnable):
                 return False, g2_baseline
 
         result = {}
-        for key in fields:
-            result[key] = 0
 
         t0 = time.perf_counter()
         for n in range(steps):
@@ -179,7 +176,13 @@ class AverageToolbox(QtCore.QRunnable):
 
                 if flag:
                     for key in fields:
-                        result[key] += xf.at(key)
+                        if key not in result:
+                            result[key] = xf.at(key)
+                        elif key != 'saxs_1d':
+                            result[key] += xf.at(key)
+                        # saxs_1d is now a dictionary; only accumulate Iq
+                        elif key == 'saxs_1d':
+                            result['saxs_1d']['Iq'] += xf.at('saxs_1d')['Iq']
                 else:
                     mask[m] = 0
 
@@ -189,7 +192,11 @@ class AverageToolbox(QtCore.QRunnable):
             logger.info('no dataset is valid; check the baseline criteria.')
         else:
             for key in fields:
-                result[key] /= np.sum(mask)
+                if key == 'saxs_1d':
+                    # only keep the Iq component, put method doesn't accept dict
+                    result['saxs_1d'] = result['saxs_1d']['Iq'] / np.sum(mask)
+                else:
+                    result[key] /= np.sum(mask)
                 if key == 'g2_err':
                     result[key] /= np.sqrt(np.sum(mask))
 
@@ -219,10 +226,12 @@ class AverageToolbox(QtCore.QRunnable):
         t.setLabel('left', 'g2 baseline')
         self.ax = t.plot(symbol='o')
         if 'avg_blmin' in self.kwargs:
-            dn = pg.InfiniteLine(pos=self.kwargs['avg_blmin'], angle=0)
+            dn = pg.InfiniteLine(pos=self.kwargs['avg_blmin'], angle=0, 
+                                 pen=pg.mkPen('r'))
             t.addItem(dn)
         if 'avg_blmax' in self.kwargs:
-            up = pg.InfiniteLine(pos=self.kwargs['avg_blmax'], angle=0)
+            up = pg.InfiniteLine(pos=self.kwargs['avg_blmax'], angle=0,
+                                 pen=pg.mkPen('r'))
             # t.addItem(pg.FillBetweenItem(dn, up))
             t.addItem(up)
         t.setMouseEnabled(x=False, y=False)
