@@ -1,5 +1,4 @@
-from PyQt5 import QtCore
-from PyQt5 import QtWidgets
+from PyQt5 import QtCore, QtWidgets
 from .viewer_ui import Ui_mainWindow as Ui
 from .viewer_kernel import ViewerKernel
 
@@ -50,11 +49,11 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             1: "saxs_1d",
             2: "stability",
             3: "intensity_t",
-            4: "average",
-            5: "g2",
-            6: "diffusion",
-            7: "twotime",
-            8: "exp_setup",
+            4: "g2",
+            5: "diffusion",
+            6: "twotime",
+            7: "average",
+            8: "metadata",
             9: "log",
             # 10: "None"
         }
@@ -83,6 +82,8 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         # additional signal-slot settings
         self.mp_2t_map.hdl.mpl_connect('button_press_event',
                                        self.update_twotime_qindex)
+        
+        self.saxs1d_lb_type.currentIndexChanged.connect(self.switch_saxs1d_line)
 
         self.tabWidget.currentChanged.connect(self.init_tab)
         # self.list_view_target.indexesMoved.connect(self.reorder_target)
@@ -206,7 +207,7 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             self.plot_intt()
         elif tab_name == 'twotime':
             self.init_twotime()
-        elif tab_name == 'exp_setup':
+        elif tab_name == 'metadata':
             self.update_hdf_list()
         elif tab_name == 'stability':
             self.update_stab_list()
@@ -295,7 +296,8 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             'qmax': self.saxs1d_qmax.value(),
             'loc': self.saxs1d_legend_loc.currentText(),
             'marker_size': self.sb_saxs_marker_size.value(),
-            'sampling': self.saxs1d_sampling.value()
+            'sampling': self.saxs1d_sampling.value(),
+            'all_phi': self.box_all_phi.isChecked(),
         }
         if kwargs['qmin'] >= kwargs['qmax']:
             self.statusbar.showMessage('check qmin and qmax')
@@ -303,6 +305,15 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
 
         self.vk.plot_saxs_1d(self.mp_saxs.hdl, **kwargs)
         self.mp_saxs.repaint()
+        # adjust the line behavior
+        self.switch_saxs1d_line()
+    
+    def switch_saxs1d_line(self):
+        if not self.check_status():
+            return
+        lb_type = self.saxs1d_lb_type.currentIndex()
+        lb_type = [None, 'slope', 'hline'][lb_type]
+        self.vk.switch_saxs1d_line(self.mp_saxs.hdl, lb_type)
 
     def init_twotime(self):
         if not self.check_status():
@@ -631,8 +642,9 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         flag, tel, qd, _, _ = self.vk.get_g2_data(max_points, rows=None)
         if not flag:
             self.statusbar.showMessage('g2 data is not consistent. abort', 999)
-        t_min = np.min(tel)
-        t_max = np.max(tel)
+        # tel is a list of arrays, which may have diffent shape;
+        t_min = np.min([t[0] for t in tel])
+        t_max = np.max([t[-1] for t in tel])
 
         def to_e(x):
             return '%.2e' % x
@@ -707,6 +719,9 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         self.vk.export_g2()
 
     def reload_source(self):
+        if self.data_state <= 0:
+            self.statusbar.showMessage('no path is specified')
+            return
         self.pushButton_11.setText('loading')
         self.pushButton_11.setDisabled(True)
         self.pushButton_11.parent().repaint()
@@ -735,13 +750,21 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
 
         # either choose a new work_dir or initialize from state=0
         # if f == curr_work_dir; then the state is kept the same;
-        if f != curr_work_dir or self.data_state == 0:
+        # if f != curr_work_dir or self.data_state == 0:
+        if self.data_state == 0:
             self.data_state = 1
             self.plot_state[:] = 0
 
         self.work_dir.setText(f)
 
-        self.vk = ViewerKernel(f, self.statusbar)
+        if self.vk is None:
+            self.vk = ViewerKernel(f, self.statusbar)
+        else:
+            self.vk.set_path(f)
+            self.vk.clear()
+
+        print(self.vk.cwd)
+
         self.reload_source()
 
         self.avg_job_table.setModel(self.vk.avg_worker)
@@ -757,6 +780,7 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             self.list_view_source.setModel(file_list)
             self.box_source.setTitle('Source: %5d' % len(file_list))
             self.box_source.parent().repaint()
+            self.list_view_source.parent().repaint()
         elif mode == 'target':
             self.list_view_target.setModel(file_list)
             self.box_target.setTitle('Target: %5d \t [Type: %s] ' %
@@ -776,7 +800,10 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
 
         target = []
         for x in self.list_view_source.selectedIndexes():
-            target.append(x.data())
+            # in some cases, it will return None
+            val = x.data()
+            if val is not None:
+                target.append(val)
 
         # only max_display items are displayed; if all are selected; then the
         # ones not displayed are also used
@@ -862,6 +889,9 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
 
         self.progress_bar.setValue(0)
         self.vk.remove_target(rmv_list)
+        # clear selection to avoid the bug: when the last one is selected, then
+        # the list will out of bounds
+        self.clear_target_selection()
 
         # if all files are removed; then go to state 1
         if self.vk.target in [[], None] or len(self.vk.target) == 0:
