@@ -59,17 +59,19 @@ class XpcsFile(object):
     """
     XpcsFile is a class that wraps an Xpcs analysis hdf file;
     """
+
     def __init__(self, fname, cwd='.', fields=None):
         self.fname = fname
         self.full_path = os.path.join(cwd, fname)
         self.cwd = cwd
 
+        # label is a short string to describe the file/filename
+        self.label = create_id(fname)
+
         self.type = get_type(self.full_path)
         self.keys, attr = self.load(fields)
         self.__dict__.update(attr)
 
-        # label is a short string to describe the file/filename
-        self.label = create_id(fname)
         self.hdf_info = None
         self.fit_summary = None
 
@@ -86,7 +88,7 @@ class XpcsFile(object):
             ans.append(f"   {key.ljust(12)}: {val.ljust(30)}")
 
         return '\n'.join(ans)
-    
+
     def __repr__(self):
         ans = str(type(self))
         ans = '\n'.join([ans, self.__str__()])
@@ -131,8 +133,10 @@ class XpcsFile(object):
     def load(self, extra_fields=None):
         # default common fields for both twotime and multitau analysis;
         fields = ['saxs_2d', "saxs_1d", 'Iqp', 'ql_sta', 'Int_t', 't0', 't1',
-                  'ql_dyn', 'type', 'dqmap', 'ccd_x0', 'ccd_y0', 'det_dist', 
-                  'pix_dim_x', 'pix_dim_y', 'X_energy', 'xdim', 'ydim']
+                  'ql_dyn', 'type', 'dqmap', 'ccd_x0', 'ccd_y0', 'det_dist',
+                  'pix_dim_x', 'pix_dim_y', 'X_energy', 'xdim', 'ydim',
+                  'avg_frames', 'stride_frames', 'snoq', 'snophi', 'dnoq',
+                  'dnophi']
 
         # extra fields for twotime analysis
         if self.type == 'Twotime':
@@ -151,8 +155,11 @@ class XpcsFile(object):
         ret = get(self.full_path, fields, 'alias')
         ret['dqmap'] = ret['dqmap'].astype(np.uint16)
 
+        # get the avg_frames and stride_frames into t0; t0 is in seconds
+        ret['t0'] = ret['t0'] * ret['avg_frames'] * ret['stride_frames']
+
         # get t_el which is in the unit of seconds;
-        if 't0' in ret and 'tau' in ret:
+        if 'tau' in ret:
             ret['t_el'] = ret['t0'] * ret['tau']
 
         if self.type == 'Twotime':
@@ -162,7 +169,51 @@ class XpcsFile(object):
             # correct g2_err to avoid fitting divergence
             ret['g2_err_mod'] = self.correct_g2_err(ret['g2_err'])
 
+        for key in ['snoq', 'snophi', 'dnoq', 'dnophi']:
+            ret[key] = int(ret[key])
+        
+        self.reshape_phi_analysis(ret)
+
         return ret.keys(), ret
+    
+    def reshape_phi_analysis(self, info):
+        new_shape = (info['snoq'], info['snophi'])
+        fields = ['sphilist', 'sqspan', 'sphispan']
+        ret = get(self.full_path, fields, mode='alias', ret_type='list')
+        sphilist, sqspan, sphispan = ret
+
+        sphi = (sphispan[1:] + sphispan[:-1]) / 2.0
+
+        if info['snophi'] > 1:
+            sq = (sqspan[1:] + sqspan[:-1]) / 2.0
+
+            nan_idx = np.isnan(sphilist)
+            saxs1d = np.zeros_like(sphilist)
+            saxs1d[~nan_idx] = info['saxs_1d']
+            saxs1d[nan_idx] = np.nan
+            saxs1d = saxs1d.reshape(*new_shape).T
+            #sphilist = sphilist.reshape(*new_shape).T
+
+            avg = np.nanmean(saxs1d, axis=0)
+            saxs1d = np.vstack([avg, saxs1d])
+
+            labels = [self.label + '_%d' % (n + 1) for n in range(info['snophi'])]
+            labels = [self.label] + labels
+
+        else:        
+            sq = info['ql_sta']
+            sq = sq[~np.isnan(sq)]
+            saxs1d = info['saxs_1d'].reshape(1, -1)
+            labels = [self.label]
+
+        info['saxs_1d'] = {
+            'q': sq,
+            'Iq': saxs1d,
+            'phi': sphi,
+            'num_lines': info['snophi'],
+            'labels': labels,
+        }
+        return
 
     def at(self, key):
         return self.__dict__[key]
@@ -175,14 +226,7 @@ class XpcsFile(object):
 
     def get_time_scale(self, group='xpcs'):
         # acquire time scale for twotime analysis
-        key_frames = [
-            '/'.join([group, 'stride_frames']),
-            '/'.join([group, 'avg_frames'])
-        ]
-        stride, avg = get(self.full_path, key_frames, mode='raw',
-                          ret_type='list')
-        time_scale = max(self.t0, self.t1) * stride * avg
-        return time_scale
+        return self.t0 
 
     def get_twotime_maps(self, group='xpcs'):
         rpath = '/'.join([group, 'output_data'])
@@ -233,7 +277,7 @@ class XpcsFile(object):
         :return:
         """
         fields = [
-            'ccd_x0', 'ccd_y0', 'det_dist', 'pix_dim_x', 'pix_dim_y', 
+            'ccd_x0', 'ccd_y0', 'det_dist', 'pix_dim_x', 'pix_dim_y',
             'X_energy', 'xdim', 'ydim'
         ]
         res = get(self.full_path, fields, mode='alias', ret_type='dict')
@@ -305,7 +349,7 @@ class XpcsFile(object):
         tree.setWindowTitle(self.fname)
         tree.resize(600, 800)
         return tree
-    
+
     def get_g2_fitting_line(self, q, tor=1E-6):
         """
         get the fitting line for q, within tor
@@ -371,7 +415,7 @@ class XpcsFile(object):
                 "for single exp, the shape of bounds must be (2, 4)"
             if fit_flag is None:
                 fit_flag = [True for _ in range(4)]
-            func = single_exp_all 
+            func = single_exp_all
         else:
             assert len(bounds[0]) == 7, \
                 "for single exp, the shape of bounds must be (2, 4)"
@@ -381,12 +425,11 @@ class XpcsFile(object):
 
         if q_range is None:
             q_range = [np.min(self.ql_dyn) * 0.95, np.max(self.ql_dyn) * 1.05]
-        
+
         if t_range is None:
             q_range = [np.min(self.t_el) * 0.95, np.max(self.t_el) * 1.05]
-        
-        
-        # create a data slice for the given range;    
+
+        # create a data slice for the given range;
         t_slice = create_slice(self.t_el, t_range)
         q_slice = create_slice(self.ql_dyn, q_range)
 
@@ -434,21 +477,21 @@ class XpcsFile(object):
             data = g2_err[:, n]
             idx = data > threshold
             avg = np.mean(data[idx])
-            g2_err_mod[np.logical_not(idx), n] = avg 
+            g2_err_mod[np.logical_not(idx), n] = avg
 
         return g2_err_mod
-    
+
     def fit_tauq(self, q_range, bounds, fit_flag):
         if self.fit_summary is None:
             return
-        
+
         x = self.fit_summary['q_val']
         q_slice = create_slice(x, q_range)
         x = x[q_slice]
 
         y = self.fit_summary['fit_val'][q_slice, 0, 1]
         sigma = self.fit_summary['fit_val'][q_slice, 1, 1]
-        
+
         # filter out those invalid fittings; failed g2 fitting has -1 err
         valid_idx = (sigma > 0)
 
@@ -469,8 +512,8 @@ class XpcsFile(object):
         fit_x = np.logspace(np.log10(np.min(x) / 1.1),
                             np.log10(np.max(x) * 1.1), 128)
 
-        fit_line, fit_val = fit_with_fixed(power_law, x, y, sigma, bounds, 
-                                           fit_flag, fit_x, p0=p0) 
+        fit_line, fit_val = fit_with_fixed(power_law, x, y, sigma, bounds,
+                                           fit_flag, fit_x, p0=p0)
 
         # fit_line and fit_val are lists with just one element;
         self.fit_summary['tauq_success'] = fit_line[0]['success']
